//
// PDFsharp - A library for processing PDF
//
// Authors:
//   Stefan Lange (mailto:Stefan.Lange@pdfsharp.com)
//
// Copyright (c) 2005-2006 empira Software GmbH, Cologne (Germany)
//
// http://www.pdfsharp.com
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

namespace PdfSharp.Forms
{
  /// <summary>
  /// Defines a zoom factor used in the preview control.
  /// </summary>
  public enum Zoom
  {
    Percent800 = 800,
    Percent600 = 600,
    Percent400 = 400,
    Percent200 = 200,
    Percent150 = 150,
    Percent100 = 100,
    Percent75 = 75,
    Percent50 = 50,
    Percent25 = 25,
    Percent10 = 10,

    /// <summary>
    /// Sets the percent value such that the document fits horizontally into the window.
    /// </summary>
    BestFit = -1,

    /// <summary>
    /// Sets the percent value such that the printable area of the document fits horizontally into the window.
    /// Currently not yet implemented and the same as ZoomBestFit.
    /// </summary>
    TextFit = -2,

    /// <summary>
    /// Sets the percent value such that the whole document fits completely into the window.
    /// </summary>
    FullPage = -3,

    /// <summary>
    /// Sets the percent value such that the document is displayed in its real physical size.
    /// </summary>
    OriginalSize = -4,
    Mininum = 10,
    Maximum = 800
  }
}
